#!/usr/bin/perl
#
# WARNING: File managed by Ansible.
#
# In theory redundant with Sympa >= 6.2.68 where we can use:
# sudo -u sympa sympa.pl add --quiet --role=owner test-dpc22@lists.cam.ac.uk
#
# However that cannot add "privileged" owners, so we need to dump and restore.

use strict;
use warnings;

my $LIST_DATA="/var/lib/sympa/list_data";
my $domain="lists.cam.ac.uk";

(@ARGV == 2) or die "$0 args: Listname email\n";

my $listname = shift(@ARGV);
my $email    = shift(@ARGV);

($listname =~ m&^[a-z0-9\-]+$&)
    or die "Invalid listname: $listname\n";

my $DIR= "${LIST_DATA}/${listname}";
( -d $DIR )
    or die "Listname $listname doesn't exist\n";

chdir($DIR) or die "chdir($DIR) failed\n";

my $lname = "${listname}\@${domain}";
my $gecos = "";
if ((-f "/opt/dist/users/cam_names.cdb") &&
    ($email =~ m&^([a-z0-9]+)\@cam\.ac\.uk$&)) {
    $gecos=`/opt/cdb/bin/cdbget $1 < /opt/dist/users/cam_names.cdb`;
}

my $cmd ="sympa.pl --dump_users --list $lname --role owner";
(system($cmd) == 0) or die "Failed to execute $cmd: $!\n";

# Copy from owner.dump to owner.dump.new, record if $email mentioned.
open my $in, "<", "owner.dump"
    or die "Failed to open owner.dump: $!\n";
open my $out, ">", "owner.dump.new" 
    or die "Failed to open owner.dump.new: $!\n";

my $existed = 0;
while (<$in>) {
    $existed = 1 if m&^email\s+${email}\n$&;
    print $out $_;
}
close($in);

unless ($existed) {
    print $out "email $email\n";
    print $out "gecos $gecos\n" if ($gecos);
    print $out "profile privileged\n";
    print $out "\n";
}
close($out);

if ($< == 0) {
    system("chown","sympa:sympa","owner.dump.new") == 0
        or die "Failed to chown owner.dump.new: $!\n";
    chmod 0640, "owner.dump.new"
        or die "Failed to chmod 0640 owner.dump.new: $!\n";
}
rename("owner.dump.new", "owner.dump")
    or die "Failed to rename owner.dump,new toowner.dump: $!\n";
       
exit(0) if $existed;
                                                            
$cmd ="sympa.pl --restore_users --list $lname --role owner";
system($cmd) == 0
    or die "Failed to execute $cmd: $!\n";

exit(0);
